@@ -1,5 +1,3 @@
-TESTHELPER_NAMES = ["PASS()", "FAIL()", "RESULT(0-100)", "CHECK_STDOUT()"];
-
 const AVAILABLE_LANGUAGES = {
     "c": "text/x-csrc",
     "cpp": "text/x-c++src",
@@ -7,23 +5,6 @@ const AVAILABLE_LANGUAGES = {
     "java": "text/x-java"
 }
 const MAX_TESTCASE_NAME_DISPLAY_LENGTH = 30;
-const CODE_PLACEHOLDER = `
-# Use PASS(), RESULT(0-100), FAIL(),
-# and CHECK_STDOUT() to instruct
-# autograder how to grade student's
-# submission
-
-def main():
-    r = student_submission.any_function()
-
-    EXPECTED_RESULT = 83
-    if r == EXPECTED_RESULT:
-        PASS()
-    else:
-        FAIL()
-
-
-main()`.trim();
 // $(document).ready(function () {
 //     window.resizeTo(1200, 900);
 // });
